@@ -70,7 +70,7 @@ class DataNullDataSource(
         has_computed_default: typing.Optional[builtins.str] = None,
         inputs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
+        depends_on: typing.Optional[typing.List[cdktf.ITerraformDependable]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
     ) -> None:
@@ -172,7 +172,7 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         self,
         *,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
+        depends_on: typing.Optional[typing.List[cdktf.ITerraformDependable]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
         has_computed_default: typing.Optional[builtins.str] = None,
@@ -211,7 +211,7 @@ class DataNullDataSourceConfig(cdktf.TerraformMetaArguments):
         return result
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
+    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
         """
         :stability: experimental
         """
@@ -344,7 +344,7 @@ class Resource(
         *,
         triggers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
+        depends_on: typing.Optional[typing.List[cdktf.ITerraformDependable]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
     ) -> None:
@@ -413,7 +413,7 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         self,
         *,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
+        depends_on: typing.Optional[typing.List[cdktf.ITerraformDependable]] = None,
         lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
         provider: typing.Optional[cdktf.TerraformProvider] = None,
         triggers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
@@ -448,7 +448,7 @@ class ResourceConfig(cdktf.TerraformMetaArguments):
         return result
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
+    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
         """
         :stability: experimental
         """
